
{*******************************************************}
{                                                       }
{       Hyper Report  Component Library                 }
{                                                       }
{       Copyright (c) 1997 Hyper Korea                  }
{                                                       }
{*******************************************************}

unit SampleCP;

interface

uses
  {$IFDEF WIN32} Windows, ComCtrls, {$ELSE} WinTypes, WinProcs, {$ENDIF}
  Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, DB, DBTables, StdCtrls, Printers,
  Buttons,
  HRClass, HRCommon, HReport;

const
  MaxQuery = 64;
type
  TCustomerPreview = class(TForm)
    Panel1: TPanel;
    ScrollBox1: TScrollBox;
    Image1: TImage;
    ZoomIn: TSpeedButton;
    ZoomOut: TSpeedButton;
    FirstPage: TSpeedButton;
    PrevPage: TSpeedButton;
    SpeedButton3: TSpeedButton;
    SpeedButton4: TSpeedButton;
    SpeedButton5: TSpeedButton;
    SpeedButton6: TSpeedButton;
    NextPage: TSpeedButton;
    LastPage: TSpeedButton;
    Panel2: TPanel;
    Process: TImage;
    btPrint: TSpeedButton;
    Step: TBitBtn;
    lbPageNo: TLabel;
    lbBackGroundMsg: TLabel;
    btExit: TSpeedButton;
    StopBackground: TSpeedButton;
    StartBackground: TSpeedButton;
    procedure StepClick(Sender: TObject);
    procedure ZoomInClick(Sender: TObject);
    procedure ZoomOutClick(Sender: TObject);
    procedure NextPageClick(Sender: TObject);
    procedure PrevPageClick(Sender: TObject);
    procedure FirstPageClick(Sender: TObject);
    procedure LastPageClick(Sender: TObject);
    procedure btPrintClick(Sender: TObject);
    procedure btExitClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormDestroy(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    FHyperReport: THyperReport;
    procedure ClearProcessStatus;
    procedure DisplayPageNo(CurrNo,LastNo:integer);
    procedure DisplayProcessStatus(Percent:integer);
    procedure CheckPageButton;
  public
    property HyperReport: THyperReport read FHyperReport write FHyperReport;
  end;

var
  CustomerPreview: TCustomerPreview;

implementation

{$R *.DFM}

procedure TCustomerPreview.DisplayPageNo(CurrNo,LastNo:integer);
begin
  with lbPageNo do begin
    Caption := Format('Page %d of %d',[CurrNo, LastNo]);
    Update;
  end;
  CheckPageButton;
end;

procedure TCustomerPreview.DisplayProcessStatus(Percent:integer);
var
  Rect: TRect;
begin
  lbBackgroundMsg.Visible := FHyperReport.isBackground;
  if (Percent < 0) then begin
      ClearProcessStatus;
      Exit;
  end;
  with Process.Canvas do begin
    Brush.Color := clYellow;
    Rect.Left   := 0;
    Rect.Top    := 0;
    Rect.Right  := Percent;
    Rect.Bottom := 20;
    FillRect(Rect);
    Process.Update;
  end;
end;

procedure TCustomerPreview.ClearProcessStatus;
begin
  with Process.Canvas do begin
    Brush.Color := clBtnFace;
    FillRect(Process.ClientRect);
  end;
end;

{ ////////////////////////////////////////////////////////////// }
{                       Zoom                                  // }
{ ////////////////////////////////////////////////////////////// }

procedure TCustomerPreview.ZoomInClick(Sender: TObject);
begin
  ZoomIn.Enabled := FHyperReport.ZoomIn;
  ZoomOut.Enabled := True;
end;

procedure TCustomerPreview.ZoomOutClick(Sender: TObject);
begin
  ZoomOut.Enabled := FHyperReport.ZoomOut;
  ZoomIn.Enabled := True;
end;

procedure TCustomerPreview.CheckPageButton;
var isBG, isEOF: Boolean;
begin
  { DebugMessage('Check:PagePos='+inttostr(PagePos)); }
  if (FHyperReport.FCurrPageNo < 1) then Exit;
  btPrint.Enabled := True;
  if (FHyperReport.FCurrPageNo > 1) then begin
      FirstPage.Enabled := True;
      PrevPage.Enabled := True;
  end else begin
      FirstPage.Enabled := False;
      PrevPage.Enabled := False;
  end;
  if (FHyperReport.FLastPagePos > FHyperReport.FCurrPagePos) then begin
      NextPage.Enabled := True;
      LastPage.Enabled := True;
  end else begin
      NextPage.Enabled := False;
      LastPage.Enabled := False;
  end;
  isBG := FHyperReport.isBackground;
  isEOF := FHyperReport.isEOF;
  StopBackground.Visible := isBG;
  StartBackground.Visible := not(isEOF or isBG);
  ZoomOut.Enabled := (FHyperReport.ZoomFactor> 20);
  ZoomIn.Enabled := (FHyperReport.ZoomFactor<100);
end;

procedure TCustomerPreview.FirstPageClick(Sender: TObject);
begin
  FHyperReport.GotoPage(hgpFirst, 0);
  CheckPageButton;
end;

procedure TCustomerPreview.PrevPageClick(Sender: TObject);
begin
  FHyperReport.GotoPage(hgpPrev, 0);
  CheckPageButton;
end;

procedure TCustomerPreview.NextPageClick(Sender: TObject);
begin
  FHyperReport.GotoPage(hgpNext, 0);
  CheckPageButton;
end;

procedure TCustomerPreview.LastPageClick(Sender: TObject);
begin
  FHyperReport.GotoPage(hgpLast, 0);
  CheckPageButton;
end;

procedure TCustomerPreview.StepClick(Sender: TObject);
begin
  FHyperReport.Step;
end;

procedure TCustomerPreview.FormCreate(Sender: TObject);
begin
  lbPageNo.Caption := '';
  Step.Visible := {$IFDEF DEBUGMODE}True{$ELSE}False{$ENDIF};
  {$IFDEF WIN32}
  with ScrollBox1 do begin
    VertScrollBar.Tracking := True;
    HorzScrollBar.Tracking := True;
  end;
  {$ENDIF}
end;

procedure TCustomerPreview.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  if Assigned(FHyperReport) then begin
    FHyperReport.OnProcess := nil;
    FHyperReport.OnChangePage := nil;
    FHyperReport.EndPreview;
    Release;
  end;
end;

procedure TCustomerPreview.btPrintClick(Sender: TObject);
begin
  FHyperReport.PreviewPrint(Printer);
end;

procedure TCustomerPreview.btExitClick(Sender: TObject);
begin
  Close;
end;

procedure TCustomerPreview.FormDestroy(Sender: TObject);
begin
  CustomerPreview := nil;
  FHyperReport := nil;
end;

procedure TCustomerPreview.FormShow(Sender: TObject);
begin
  with FHyperReport do begin
    ClearProcessStatus;
    PreviewImage := Image1;
    PreviewScrollBox := ScrollBox1;
    OnProcess    := DisplayProcessStatus;
    OnChangePage := DisplayPageNo;
    if (FHyperReport.ShowModal) then StartPreview;
  end;
end;

end.
